@@ -113,10 +113,7 @@ public:
     CollectionListItem *lookup(const QString &file) const;
 
     virtual CollectionListItem *createItem(const FileHandle &file,
-                                     QTreeWidgetItem * = 0,
-                                     bool = false);
-
-    void emitVisibleColumnsChanged() { emit signalVisibleColumnsChanged(); }
+                                     QTreeWidgetItem * = nullptr);
 
     virtual void clearItems(const PlaylistItemList &items);
 
@@ -169,9 +166,8 @@ signals:
      *
      * \see Playlist::hideColumn()
      * \see Playlist::showColumn()
-     * \see Playlsit::isColumnVisible()
+     * \see Playlist::isColumnVisible()
      */
-    void signalVisibleColumnsChanged();
     void signalNewTag(const QString &, unsigned);
     void signalRemovedTag(const QString &, unsigned);
 
